@@ -2,11 +2,12 @@ package Crypt::NaCl::Tweet;
 use strict;
 use warnings;
 BEGIN {
-  our $VERSION = '0.02';
+  our $VERSION = '0.03';
   require XSLoader;
   XSLoader::load(__PACKAGE__, $VERSION);
 }
 BEGIN {
+  sub random_bytes;
   if (eval { require Sys::GetRandom; 1; }) {
     *random_bytes = sub { Sys::GetRandom::random_bytes($_[0]) };
   }
@@ -150,6 +151,12 @@ use constant verify_BYTES => 16;
 use constant verify_16_BYTES => 16;
 use constant verify_32_BYTES => 32;
 
+sub box_keypair {
+  my $sk = random_bytes(32);
+  my $pk = scalarmult_base($sk);
+  return ($pk, $sk);
+}
+
 1;
 
 __END__
